{% load nexus_helpers %}
<div id="navigation">
    <div class="wrapper">
        {% if category_link_set %}
            <ul>
                {% for category in category_link_set %}
                    {% if category.label and category.links|length > 1 %}
                        <li{% if category.active %} class="selected"{% endif %}>
                            <span>{{ category.label }}</span>
                            <ul>
                                {% for title, link, active in category.links %}
                                    <li{% if active %} class="selected"{% endif %}>
                                        <a href="{{ link }}">{{ title }}</a>
                                    </li>
                                {% endfor %}
                            </ul>
                        </li>
                    {% else %}
                        {% for title, link, active in category.links %}
                            <li{% if active %} class="selected"{% endif %}>
                                <a href="{{ link }}">{{ title }}</a>
                            </li>
                        {% endfor %}
                    {% endif %}
                {% endfor %}
            </ul>
        {% endif %}
    </div>
</div>
