{% extends "nexus/base.html" %}

{% load i18n %}

{% block heading %}{% trans "Dashboard" %}{% endblock %}

{% block breadcrumbs %}{% endblock %}

{% block content %}
    <div id="dashboard">
        {% for title, content, link in module_set %}
            <div class="dashboard-module">
                <div class="dashboard-module-title">
                    {{ title }}
                    {% if link %}
                        <a href="{{ link }}" class="go-link">More &rsaquo;</a>
                    {% endif %}
                </div>
                <div class="dashboard-module-content">
                    <div class="clearfix">
                        {{ content }}
                    </div>
                </div>
            </div>
        {% empty %}
            <p>We did not detect any Nexus dashboard modules.</p>
        {% endfor %}
    </div>
{% endblock %}
